'use strict';

var externalEsModule = require('external-esModule');



module.exports = externalEsModule.default;
